package net.yaoyi.gulop.member.auth.controller;


import com.ancun.netsign.model.ContractInput;
import com.ancun.netsign.model.ContractUserInput;
import com.ancun.netsign.model.FileUploadInput;
import com.ancun.netsign.model.FileUrlInput;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import net.yaoyi.gulop.member.auth.service.GigConfigService;
import net.yaoyi.gulop.member.auth.util.CommonResult;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.io.File;
import java.io.IOException;
import java.security.NoSuchAlgorithmException;
import java.util.List;
import java.util.Map;

@Slf4j
@RestController
@RequestMapping("/api/sign/contract")
@CrossOrigin(origins = "http://localhost:8080",
        allowedHeaders = "*",
        methods = {RequestMethod.GET, RequestMethod.POST})
//@Api(tags = "用户认证服务接口")
@RequiredArgsConstructor
public class SignContractController {

    private final GigConfigService gigConfigService;

    //获取签约列表
    @GetMapping("/contract-list")
    public CommonResult getList() {

        return CommonResult.ok(gigConfigService.getSignList(2L));
    }

    //签约
    @PostMapping("/sign")
    public CommonResult signContract(@RequestBody Map<String, Long> request) {
        try {
            if (request.get("config_id") == null){
                throw new RuntimeException("获取签约信息失败");
            }
            return gigConfigService.signContract(request.get("config_id"),2L );
        }catch (Exception e) {
            e.printStackTrace();
            return CommonResult.failed(e.getMessage());
        }
    }

    @PostMapping("/create-contract")
    public CommonResult createContract(@RequestBody ContractInput contractInput) {
        return gigConfigService.createContract(contractInput);
    }

    @PostMapping("/create-contract1")
    public CommonResult createContract1(@RequestParam("contractId") String contractId, @RequestParam("file") MultipartFile file) throws IOException {
        ContractInput contractInput = new ContractInput();
        contractInput.setContractNo(contractId);
        contractInput.setContractName(contractId);
        contractInput.setValidityTime(30);
        contractInput.setSignOrder(1);
        return gigConfigService.createContract1(contractInput, file);
    }

    @PostMapping("/add-signer")
    public CommonResult addSigner(@RequestBody List<ContractUserInput> request) {
        return gigConfigService.addSigner(request);
    }

    @PostMapping("/uploadFileByUrl")
    public CommonResult uploadFileByUrl(@RequestBody FileUrlInput urlInput){
        return gigConfigService.uploadFileByUrl(urlInput);
    }

    @GetMapping("/getFileUploadInput")
    public CommonResult getFileUploadInput(@RequestParam String url) throws IOException, NoSuchAlgorithmException {
        return gigConfigService.getFileUploadInput(url);
    }

    @PostMapping("/getUploadFileUrl")
    public CommonResult getUploadFileUrl(@RequestBody FileUploadInput uploadInput){
        return gigConfigService.getUploadFileUrl(uploadInput);
    }

    @PostMapping("/uploadFile")
    public CommonResult uploadFile(@RequestParam String url, @RequestParam String fileUrl) throws Exception {
        File file = new File(fileUrl);

        return gigConfigService.uploadFile(url,fileUrl);
    }

    //查看合同信息（同步合同信息和状态）
    @PostMapping("/sign-check")
    public CommonResult signCheck(@RequestBody Map<String, String> request) {
        try {
            if (!request.containsKey("contract_id")){
                throw new RuntimeException("获取签约信息失败");
            }
            return gigConfigService.signCheck(Long.valueOf(request.get("contract_id")),2L );
        }catch (Exception e) {
            e.printStackTrace();
            return CommonResult.failed(e.getMessage());
        }
    }


    //获取报告列表
    @GetMapping("/report-list")
    public CommonResult getReportList() {

        return CommonResult.ok(gigConfigService.getReportList());
    }



    //下载报告
    @PostMapping("/report-down")
    public CommonResult getReportDown(@RequestBody Map<String, Long> request) {
        try {
            if (request.get("config_id") == null){
                throw new RuntimeException("获取报告信息失败");
            }
            return gigConfigService.getReportDown(request.get("config_id"));
        }catch (Exception e) {
            e.printStackTrace();
            return CommonResult.failed(e.getMessage());
        }
        }

}
