package net.yaoyi.gulop.member.auth.util;

import com.ancun.netsign.model.FileDto;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.net.HttpURLConnection;
import java.net.URL;

public class RemoteFileUtils {

    public static FileDto fromUrl(String imageUrl) throws IOException {
        // 创建URL对象并打开连接
        URL url = new URL(imageUrl);
        HttpURLConnection connection = (HttpURLConnection) url.openConnection();
        connection.setRequestMethod("GET");
        connection.connect();

        // 检查HTTP响应状态
        int statusCode = connection.getResponseCode();
        if (statusCode != HttpURLConnection.HTTP_OK) {
            throw new IOException("Failed to fetch image: HTTP " + statusCode);
        }

        // 获取输入流和文件名
        InputStream inputStream = connection.getInputStream();
        String fileName = extractFileNameFromUrl(url);

        // 封装到FileDto
        FileDto fileDto = new FileDto();
        fileDto.setFileName(fileName);
        fileDto.setFileInputStream(inputStream);
        // fileDto.setFilePath(""); // 根据需求设置本地存储路径（如果有）

        return fileDto;
    }

    public static File downloadFileFromUrl(String url) throws IOException {
        FileDto fileDto = fromUrl(url);

        String extension = fileDto.getFileName() == null ? "" : fileDto.getFileName().substring(fileDto.getFileName().lastIndexOf("."));
        String fileNameNoExtension = fileDto.getFileName() == null ? "" : fileDto.getFileName().substring(0, fileDto.getFileName().lastIndexOf("."));

//        File directory = new File(System.getProperty("java.io.tmpdir"));
//        File file = new File(directory, fileDto.getFileName());
        File file = File.createTempFile(fileNameNoExtension,extension);

//        if (file.exists()) {
//            boolean deleted = file.delete();
//        }

        try(FileOutputStream fos = new FileOutputStream(file)){
            byte[] buffer = new byte[1024];
            int bytesRead;
            while ((bytesRead = fileDto.getFileInputStream().read(buffer)) != -1) {
                fos.write(buffer, 0, bytesRead);
            }
        }

        return file;
    }

    private static String extractFileNameFromUrl(URL url) {
        String path = url.getPath();
        // 移除查询参数
        int queryIndex = path.indexOf('?');
        if (queryIndex > 0) {
            path = path.substring(0, queryIndex);
        }
        // 提取最后的文件名部分
        int slashIndex = path.lastIndexOf('/');
        return (slashIndex < 0) ? "default.jpg" : path.substring(slashIndex + 1);
    }
}